"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const crypto_1 = require("crypto");
const rxjs_1 = require("rxjs");
const operators_1 = require("rxjs/operators");
const realtime_1 = __importDefault(require("./realtime"));
class RealtimeAuthClient extends realtime_1.default {
    constructor(key, secret) {
        if (!key || !secret) {
            throw new Error('API key and/or secret are required.');
        }
        super();
        this.auth$ = rxjs_1.from(this.auth(key, secret)).pipe(operators_1.shareReplay());
    }
    childOrderEvents() {
        return this.subscribeAuth('child_order_events').pipe(operators_1.mergeAll());
    }
    parentOrderEvents() {
        return this.subscribeAuth('parent_order_events').pipe(operators_1.mergeAll());
    }
    subscribeAuth(channel) {
        return this.auth$.pipe(operators_1.switchMap(() => this.subscribe(channel)));
    }
    auth(key, secret) {
        const timestamp = Date.now();
        const nonce = crypto_1.randomBytes(16).toString('hex');
        const signature = crypto_1.createHmac('sha256', secret)
            .update(timestamp + nonce).digest('hex');
        return this.call('auth', {
            api_key: key, timestamp, nonce, signature,
        });
    }
}
exports.default = RealtimeAuthClient;
