"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const rxjs_1 = require("rxjs");
const webSocket_1 = require("rxjs/webSocket");
const operators_1 = require("rxjs/operators");
class RealtimeClient {
    constructor() {
        this.subscribed = {};
        this.subject = webSocket_1.webSocket({
            url: 'wss://ws.lightstream.bitflyer.com/json-rpc',
            // eslint-disable-next-line global-require
            WebSocketCtor: require('ws'),
        });
        this.subject.subscribe();
    }
    unsubscribe() {
        this.subject.unsubscribe();
    }
    board(product) {
        return this.subscribe(`lightning_board_${product}`);
    }
    boardSnapshot(product) {
        return this.subscribe(`lightning_board_snapshot_${product}`);
    }
    executions(product) {
        return this.subscribe(`lightning_executions_${product}`).pipe(operators_1.mergeAll());
    }
    ticker(product) {
        return this.subscribe(`lightning_ticker_${product}`);
    }
    subscribe(channel) {
        if (!this.subscribed[channel]) {
            this.subscribed[channel] = rxjs_1.concat(rxjs_1.from(this.call('subscribe', { channel })).pipe(operators_1.ignoreElements()), this.channelMessage(channel));
        }
        return this.subscribed[channel];
    }
    channelMessage(channel) {
        return this.subject.asObservable().pipe(operators_1.map((x) => x), operators_1.filter((x) => { var _a; return x.method === 'channelMessage' && ((_a = x.params) === null || _a === void 0 ? void 0 : _a.channel) === channel; }), operators_1.map((x) => { var _a; return (_a = x.params) === null || _a === void 0 ? void 0 : _a.message; }), operators_1.share());
    }
    call(method, params) {
        return __awaiter(this, void 0, void 0, function* () {
            const id = Date.now().toString();
            this.subject.next({
                jsonrpc: '2.0',
                method,
                params,
                id,
            });
            const response = yield this.subject.pipe(operators_1.filter((res) => res.id === id), operators_1.first()).toPromise();
            if (response.error) {
                throw new Error(response.error.message);
            }
            return response;
        });
    }
}
exports.default = RealtimeClient;
